const common = {
	/**
	* 转义富文本标签
	* @param { String } temp 后台返回需要处理的富文本
	* @return { String } 处理好的富文本
	*/
	unescapeHTML(temp){
		if(!temp) return '';
		temp = "" + temp;
		return temp.replace(/&lt;/g, "<").replace(/&gt;/g, ">").replace(/&amp;/g, "&").replace(/&quot;/g, '"').replace(/&apos;/g, "'");
	},
	/**
	* 上传文件(只能单文件上传)
	* @param { String } url 服务器 url
	* @param { String } name 上传类型 goods-商品图片 avatar-用户头像 video-视频 store_logo-店铺logo store_banner-店铺banner store_avatar-店铺头像 common-其他图片
	* @param { String } filePath 要上传文件资源的路径
	* @return { object } promise 对象 resolve 返回文件服务器地址 reject 返回错误信息
	*/
	uploadFile({ url, name, filePath }) {
		const token = uni.getStorageSync('token');
		const promise =  new Promise((resolve, reject) => {
			uni.uploadFile({
				url: url,
				header: { "authorization": 'Bearer' + " " + token },
				filePath: filePath,
				name: name,
				formData: {
					name: name,
				},
				success: uploadFileRes => {
					const data = JSON.parse(uploadFileRes.data);
					// console.log(data);
					if(data.errCode == 0) {
						resolve(data.data);
					} else {
						reject(data.message);
					}
				},
				fail(){
					reject('上传失败');
				}
			})
		});
		return promise;
	},
	/**
	* 将 php 时间戳转化为时分秒
	* @param { String } timestamp php 时间戳
	* @param { String } format 间隔符 默认 '26:14:25'
	* @return { String } 格式化时间
	*/
	getLineTime({ timestamp, format } = {}) {
		const days = Math.floor(timestamp / (24 * 3600 * 1000));
		//计算出小时数
		const leave1 = timestamp % (24 * 3600 * 1000) // 计算天数后剩余的毫秒数
		let hours = Math.floor(leave1 / (3600 * 1000));
		//计算相差分钟数
		const leave2 = leave1 % (3600 * 1000) // 计算小时数后剩余的毫秒数
		const minutes = Math.floor(leave2 / (60 * 1000))
		//计算相差秒数
		const leave3 = leave2 % (60 * 1000) // 计算分钟数后剩余的毫秒数
		const seconds = Math.round(leave3 / 1000)
		// 把天数算在小时里
		hours = days * 24 + hours;
		let result;
		if(format) result = hours + format + minutes + format + seconds;
		else result = hours + ':' + minutes + ':' + seconds;
		return result;
	},
	/**
	* 广告位跳转
	* @param { String } type 跳转类型
	* @param { String | Number } id 跳转id 商品id/商家id...
	* @return { undefined } undefined
	*/
	jumpPage({ type, id }) {
		let url;
		switch (type) {
			case 1:
				url = '/pageB/sdetails/index?id=' + id;
				break;
			case 2:
				url = '/pageC/merchant/index?id=' + id;
				break;
			case 3:
				url = '/pageE/mine/MemberServe?current=1'
				break;
			default:
				break;
		}
		// console.log(url);
		uni.navigateTo({ url: url });
	},
}
export default common;